"""
Verna: A simple module to handle RGBA colors
"""

__version__ = "0.0.2"

from verna.verna import Color

__all__ = ['Color']
